##  Introduction
A scheduled change essentially indicates the impacts of transformation items on the impacted fact sheet attribute. Conversely, you can schedule changes directly on individual fact sheet attributes to create corresponding transformation items.
The scheduled change enhances visibility and usability around transformation planning by allowing you to track and manage upcoming changes — impacts of transformation items — directly within a fact sheet’s detail page, reducing the need to navigate to the Transformations tab.
This makes it easier for stakeholders to stay informed, ensuring they are always aware of changes affecting their fact sheets, while also simplifying transformation management and updates.
